@@ -1,5 +1,7 @@
 """Tmuxp example plugin for reattaching session."""
 
+from __future__ import annotations
+
 import typing as t
 
 from tmuxp.plugin import TmuxpPlugin
@@ -14,6 +16,6 @@ class PluginReattach(TmuxpPlugin):
     def __init__(self) -> None:
         self.message: str = "[+] This is the Tmuxp Test Plugin"
 
-    def reattach(self, session: "Session") -> None:
+    def reattach(self, session: Session) -> None:
         """Apply hook that runs for tmux on session reattach."""
         session.rename_session("plugin_test_r")
